@@ -178,10 +178,12 @@ def add_uris(config,
 
 
 def cmd_persist_config(config, filename, header=None,
-                       pretty=False, sort_with_localname=False):
+                       pretty=False, sort_with_localname=False,
+                       spec=True, exact=False, vcs_only=False):
     """writes config to given file in yaml syntax"""
     generate_config_yaml(config, filename, header,
-                         pretty, sort_with_localname)
+                         pretty, sort_with_localname,
+                         spec, exact, vcs_only)
 
 
 def cmd_version():
@@ -335,7 +337,8 @@ def cmd_install_or_update(
     localnames=None,
     num_threads=1,
     timeout=None,
-    verbose=False):
+    verbose=False,
+    shallow=False):
     """
     performs many things, generally attempting to make
     the local filesystem look like what the config specifies,
@@ -395,7 +398,8 @@ def cmd_install_or_update(
                                  backup_path=self.report.backup_path,
                                  inplace=self.report.inplace,
                                  timeout=self.report.timeout,
-                                 verbose=self.report.verbose)
+                                 verbose=self.report.verbose,
+                                 shallow=self.report.shallow)
             return {}
 
     work = DistributedWork(capacity=len(preparation_reports),
@@ -404,6 +408,7 @@ def cmd_install_or_update(
     for report in preparation_reports:
         report.verbose = verbose
         report.timeout = timeout
+        report.shallow = shallow
         thread = Installer(report)
         work.add_thread(thread)
 
